import { CommonModule } from '@angular/common';
import {
  Component,
  EventEmitter,
  Input,
  OnDestroy,
  OnInit,
  Output,
} from '@angular/core';
import { Subscription } from 'rxjs';
import { ModalService } from '../../services/modal/modal.service';

@Component({
  selector: 'app-confirm-modal',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './confirm-modal.component.html',
})
export class ConfirmModalComponent implements OnInit, OnDestroy {
  @Input() message: string = 'Es-tu sûr de vouloir supprimer ?';
  @Input() pinId: string = '';
  @Input() pinOpened!: EventEmitter<void>;

  @Output() confirmed = new EventEmitter<void>();
  @Output() cancelled = new EventEmitter<void>();

  modalId: string = '';

  isOpen = false;
  private subscription!: Subscription;

  constructor(private modalService: ModalService) {}

  ngOnInit() {
    this.modalId = 'confirm-modal-' + this.pinId;

    this.subscription = this.modalService
      .getModalState(this.modalId)
      .subscribe((state) => {
        this.isOpen = state;
      });

    this.pinOpened.subscribe(() => {
      this.moveModalToBody();
    });
  }

  ngOnDestroy() {
    this.subscription?.unsubscribe();
  }

  confirm() {
    this.confirmed.emit();
    this.modalService.closeModal(this.modalId);
  }

  cancel() {
    this.cancelled.emit();
    this.modalService.closeModal(this.modalId);
  }

  closeModal() {
    this.isOpen = false;
    this.modalService.closeModal(this.modalId);
  }

  private moveModalToBody(): void {
    const modal = document.getElementById(this.modalId);
    if (modal && modal.parentElement !== document.body) {
      document.body.appendChild(modal);
    }
  }
}
