import { CommonModule } from '@angular/common';
import {
  Component,
  EventEmitter,
  Input,
  OnChanges,
  Output,
  SimpleChanges,
} from '@angular/core';

@Component({
  selector: 'app-drag-drop',
  imports: [CommonModule],
  templateUrl: './drag-drop.component.html',
})
export class DragDropComponent implements OnChanges {
  @Input() initialFiles: string[] = [];
  @Input() errorMessage: string = '';
  fileNames: string[] = [];
  @Output() filesSelected = new EventEmitter<FileList>();
  @Output() fileRemoved = new EventEmitter<string>();

  ngOnChanges(changes: SimpleChanges) {
    if (changes['initialFiles']) {
      this.fileNames = [...this.initialFiles];
    }
  }

  ngOnInit() {
    if (this.initialFiles && this.initialFiles.length > 0) {
      this.fileNames = [...this.initialFiles];
    }
  }

  onFilesSelected(event: Event): void {
    const input = event.target as HTMLInputElement;
    if (input.files) {
      this.updateFileNames(input.files);
      this.filesSelected.emit(input.files);
    }
  }

  onDrop(event: DragEvent): void {
    event.preventDefault();
    event.stopPropagation();
    if (event.dataTransfer && event.dataTransfer.files) {
      this.updateFileNames(event.dataTransfer.files);
      this.filesSelected.emit(event.dataTransfer.files);
    }
  }

  onDragOver(event: DragEvent): void {
    event.preventDefault();
  }

  onDragLeave(event: DragEvent): void {
    event.preventDefault();
  }

  updateFileNamesFromFileList(files: FileList): void {
    this.fileNames = Array.from(files).map((file) => file.name);
  }

  private updateFileNames(files: FileList): void {
    const newFileNames = Array.from(files).map(file => file.name);
    this.fileNames = [...this.fileNames, ...newFileNames];
  }

  removeFile(fileName: string, event: Event): void {
    event.stopPropagation(); // Empêcher la propagation du clic
    const index = this.fileNames.indexOf(fileName);
    if (index > -1) {
      this.fileNames.splice(index, 1);
      this.fileRemoved.emit(fileName);
    }
  }
}
