import { Injectable } from '@angular/core';
import { environment } from '../../../environment';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AuthService } from '../auth/auth.service';

@Injectable({
  providedIn: 'root'
})
export class ImageService {
  private apiUrl = environment.apiURL;

  constructor(
    private http: HttpClient,
    private authService: AuthService
  ) { }

  getImage(imageId: string): Observable<Blob> {
    const headers = this.authService.getAuthHeaders();

    return this.http.get(`${this.apiUrl}/image/${imageId}`, {
      headers,
      responseType: 'blob'
    });
  }

  postImage(image: File): Observable<any> {
    const headers = this.authService.getAuthHeaders();

    const formData = new FormData();
    formData.append('image', image);

    return this.http.post(`${this.apiUrl}/image/pin/null/add`, formData, { headers });
  }

  getImageMetadata(imageId: string): Observable<any> {
    const headers = this.authService.getAuthHeaders();

    return this.http.get(`${this.apiUrl}/image/${imageId}/metadata`, { headers });
  }
}