import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { environment } from '../../../environment';
import { Pin } from '../../model/Pin';
import { AuthService } from '../auth/auth.service';

@Injectable({
  providedIn: 'root',
})
export class PinService {
  allPins: Pin[] = [];
  filteredPins: Pin[] = [];

  private apiURL = environment.apiURL;

  constructor(private http: HttpClient, private authService: AuthService) {}

  getPins(): any {
    const url = `${this.apiURL}/pins`;
    const headers = this.authService.getAuthHeaders();
    headers.set('Content-Type', 'application/json');

    return this.http.get<any>(url, { headers });
  }

  addPin(pin: Pin) {
    const url = `${this.apiURL}/pin/add`;
    const headers = this.authService.getAuthHeaders();
    headers.set('Content-Type', 'application/json');

    return this.http.post<any>(url, pin, { headers });
  }

  updatePin(id: string, pin: Pin) {
    const url = `${this.apiURL}/pin/${id}`;
    const headers = this.authService.getAuthHeaders();
    headers.set('Content-Type', 'application/json');

    // Obtenir les coordonnées GPS à partir de l'adresse
    return this.http.patch<any>(url, pin, { headers });
  }

  deletePin(id: string) {
    const url = `${this.apiURL}/pin/${id}`;
    const headers = this.authService.getAuthHeaders();
    headers.set('Content-Type', 'application/json');

    return this.http.delete<any>(url, { headers });
  }

  sharePin(pinId: string, friendId: string) {
    const url = `${this.apiURL}/pin/${pinId}/share`;
    const headers = this.authService.getAuthHeaders();
    headers.set('Content-Type', 'application/json');

    return this.http.post<any>(url, { friend_id: friendId }, { headers });
  }

  getPinShares(pinId: string) {
    const url = `${this.apiURL}/pin/${pinId}/shares`;
    const headers = new HttpHeaders({
      'Content-Type': 'application/json',
      Authorization: 'Bearer ' + localStorage.getItem('auth_token'),
    });
    return this.http.get<any>(url, { headers });
  }
}
